@@ -1,14 +1,14 @@
 #' @title Network Scores
 #'
 #' @description This function computes network scores computed based on
-#' each node's \code{strength} within each community in the network 
-#' (see \code{\link[EGAnet]{net.loads}}). These values are used as "network loadings" 
+#' each node's \code{strength} within each community in the network
+#' (see \code{\link[EGAnet]{net.loads}}). These values are used as "network loadings"
 #' for the weights of each variable.
-#' 
+#'
 #' Network scores are computed as a formative composite rather than a reflective factor.
 #' This composite representation is consistent with no latent factors that psychometric
 #' network theory proposes.
-#' 
+#'
 #' Scores can be computed as a "simple" structure, which is equivalent to a weighted
 #' sum scores or as a "full" structure, which is equivalent to an EFA approach.
 #' Conservatively, the "simple" structure approach is recommended until further
@@ -26,38 +26,38 @@
 #'
 #' @param loading.method Character (length = 1).
 #' Sets network loading calculation based on implementation
-#' described in \code{"BRM"} (Christensen & Golino, 2021) or
-#' an \code{"experimental"} implementation.
-#' Defaults to \code{"BRM"}
-#' 
+#' described in \code{"original"} (Christensen & Golino, 2021) or
+#' the \code{"revised"} (Christensen et al., 2024) implementation.
+#' Defaults to \code{"revised"}
+#'
 #' @param rotation Character.
-#' A rotation to use to obtain a simpler structure. 
+#' A rotation to use to obtain a simpler structure.
 #' For a list of rotations, see \code{\link[GPArotation]{rotations}} for options.
 #' Defaults to \code{NULL} or no rotation.
 #' By setting a rotation, \code{scores} estimation will be
 #' based on the rotated loadings rather than unrotated loadings
-#' 
+#'
 #' @param scores Character (length = 1).
 #' How should scores be estimated?
 #' Defaults to \code{"network"} for network scores.
 #' Set to other scoring methods which will be computed using
 #' \code{\link[psych]{factor.scores}} (see link for arguments
 #' and explanations for other methods)
-#' 
+#'
 #' @param loading.structure Character (length = 1).
 #' Whether simple structure or the saturated loading matrix
 #' should be used when computing scores.
 #' Defaults to \code{"simple"}
-#' 
-#' \code{"simple"} structure more closely mirrors sum scores and CFA; 
+#'
+#' \code{"simple"} structure more closely mirrors sum scores and CFA;
 #' \code{"full"} structure more closely mirrors EFA
-#' 
+#'
 #' Simple structure is the more "conservative" (established) approach
 #' and is therefore the default. Treat \code{"full"} as experimental
 #' as proper vetting and validation has not been established
 #'
 #' @param impute Character (length = 1).
-#' If there are any missing data, then imputation can be implemented. 
+#' If there are any missing data, then imputation can be implemented.
 #' Available options:
 #'
 #' \itemize{
@@ -71,8 +71,8 @@
 #' for that variable
 #'
 #' }
-#' 
-#' @param ... Additional arguments to be passed on to 
+#'
+#' @param ... Additional arguments to be passed on to
 #' \code{\link[EGAnet]{net.loads}} and
 #' \code{\link[psych]{factor.scores}}
 #'
@@ -81,7 +81,7 @@
 #' \item{scores}{A list containing the standardized (\code{std.scores})
 #' rotated (\code{rot.scores}) scores. If \code{rotation = NULL}, then
 #' \code{rot.scores} will be \code{NULL}}
-#' 
+#'
 #' \item{loadings}{Output from \code{\link[EGAnet]{net.loads}}}
 #'
 #' @examples
@@ -102,21 +102,26 @@
 #' Christensen, A. P., & Golino, H. (2021).
 #' On the equivalency of factor and network loadings.
 #' \emph{Behavior Research Methods}, \emph{53}, 1563-1580.
-#' 
+#'
 #' \strong{Preliminary simulation for scores} \cr
 #' Golino, H., Christensen, A. P., Moulder, R., Kim, S., & Boker, S. M. (2021).
 #' Modeling latent topics in social media using Dynamic Exploratory Graph Analysis: The case of the right-wing and left-wing trolls in the 2016 US elections.
 #' \emph{Psychometrika}.
 #'
+#' \strong{Revised network loadings} \cr
+#' Christensen, A. P., Golino, H., Abad, F. J., & Garrido, L. E. (2024).
+#' Revised network loadings.
+#' \emph{PsyArXiv}.
+#'
 #' @author Alexander P. Christensen <alexpaulchristensen@gmail.com> and Hudson F. Golino <hfg9s at virginia.edu>
 #'
 #' @export
 #'
 # Network Scores ----
-# Updated 24.10.2023
+# Updated 12.08.2024
 net.scores <- function (
-    data, A, wc, 
-    loading.method = c("BRM", "experimental"),
+    data, A, wc,
+    loading.method = c("original", "revised"),
     rotation = NULL,
     scores = c(
       "Anderson", "Bartlett", "components",
@@ -127,16 +132,16 @@ net.scores <- function (
     ...
 )
 {
-  
+
   # All argument errors are handled here or in `net.loads`
-  
+
   # Error on:
   # 1. missing data
   # 2. symmetric matrix input as data
   if(missing(data)){ # Check for missing data
     .handleSimpleError(
       h = stop,
-      msg = "Input for 'data' is missing. To compute scores, the original data are necessary", 
+      msg = "Input for 'data' is missing. To compute scores, the original data are necessary",
       call = "net.scores"
     )
   }else if(is_symmetric(data)){ # Check for symmetric matrix
@@ -146,35 +151,36 @@ net.scores <- function (
       call = "net.scores"
     )
   }
-  
+
   # Ensure data is a matrix
-  data <- as.matrix(usable_data(data, verbose = TRUE)) 
-  
+  data <- as.matrix(usable_data(data, verbose = TRUE))
+
   # Get ellipse arguments
   ellipse <- list(...)
-  
+
   # Check for defunct "method"
   if("method" %in% names(ellipse)){
     scores <- ellipse$method
   }
-  
+
   # Check for missing arguments (argument, default, function)
-  loading.method <- set_default(loading.method, "brm", net.loads)
+  # loading.method <- set_default(loading.method, "brm", net.loads)
+  # Push default check to `net.laods`
   scores <- set_default(scores, "network", net.scores)
   loading.structure <- set_default(loading.structure, "simple", net.scores)
   impute <- set_default(impute, "none", net.scores)
-  
+
   # Perform imputation
   if(impute != "none"){
     data <- imputation(data, impute)
   }
-  
+
   # Compute network loadings (will handle `EGA` objects)
   loadings <- net.loads(
     A = A, wc = wc, loading.method = loading.method,
     rotation = rotation, ...
   )
-  
+
   # Return results
   return(
     list(
@@ -184,7 +190,7 @@ net.scores <- function (
       loadings = loadings
     )
   )
-  
+
 }
 
 #' @noRd
@@ -192,31 +198,31 @@ net.scores <- function (
 # Updated 04.08.2023
 imputation <- function(data, impute)
 {
-  
+
   # Get imputation function
   impute_values <- switch(
     impute,
     "mean" = colMeans(data, na.rm = TRUE),
     "median" = nvapply(as.data.frame(data), median, na.rm = TRUE)
   )
-  
+
   # Get missing data
   missing_data <- which(is.na(data), arr.ind = TRUE)
-  
+
   # Loop over unique columns
   for(column in unique(missing_data[,"col"])){
-    
+
     # Obtain target rows
     target_rows <- missing_data[,"row"][missing_data[,"col"] == column]
-    
+
     # Populate data
     data[target_rows, column] <- impute_values[column]
-    
+
   }
-  
+
   # Return data
   return(data)
-  
+
 }
 
 #' @noRd
@@ -224,32 +230,32 @@ imputation <- function(data, impute)
 # Consistent with hierarchical CFA
 # Updated 28.07.2023
 zero_out <- function(loadings, wc, loading.structure){
-  
+
   # Check for loading structure
   if(loading.structure == "simple"){
-    
+
     # Get names of memberships
     wc_names <- names(wc)
-    
+
     # Get loadings names
     loadings_names <- dimnames(loadings)[[2]]
-    
+
     # Loop over unique memberships
     for(membership in unique(wc)){
-      
+
       # Set cross-loadings to zero
       loadings[
         wc_names[wc == membership],
         loadings_names != membership
       ] <- 0
-      
+
     }
-    
+
   }
-  
+
   # Return loadings
   return(loadings)
-  
+
 }
 
 #' @noRd
@@ -259,10 +265,10 @@ compute_scores <- function(
     loadings, data, scores, loading.structure
 )
 {
-  
+
   # Method must exist, so continue
   if(scores == "network"){
-    
+
     # Compute unrotated scores
     unrotated <- network_scores(
       data = data,
@@ -271,7 +277,7 @@ compute_scores <- function(
         loading.structure
       )
     )
-    
+
     # Compute rotated scores (if available)
     if(!is.null(loadings$rotated)){
       rotated <- network_scores(
@@ -283,27 +289,27 @@ compute_scores <- function(
         )
       )
     }else{rotated <- NULL}
-    
+
   }else{
-    
+
     # Switch lowercase method back to appropriate case
     scores <- switch(
       scores,
-      "anderson" = "Anderson", 
+      "anderson" = "Anderson",
       "bartlett" = "Bartlett",
       "components" = "components",
-      "harman" = "Harman", 
+      "harman" = "Harman",
       "tenberge" = "tenBerge",
       "thurstone" = "Thurstone"
     )
-    
+
     # Compute unrotated scores
     unrotated <- psych::factor.scores(
       x = data,
       f = loadings$std,
       method = scores
     )$scores
-    
+
     # Compute rotated scores (if available)
     if(!is.null(loadings$rotated)){
       rotated <- psych::factor.scores(
@@ -313,9 +319,9 @@ compute_scores <- function(
         method = scores
       )$scores
     }else{rotated <- NULL}
-    
+
   }
-  
+
   # Return scores
   return(
     list(
@@ -323,7 +329,7 @@ compute_scores <- function(
       rot.scores = rotated
     )
   )
-  
+
 }
 
 #' @noRd
